// IIFE
var overview = overview || {};
(function(library) {
  // global jQuery object is passed as a parameter
  library(window.jQuery, window, document);

  }(function($, window, document) { 
	// BEGIN CODE
	// ONLOAD
	var sampleData = false;
	$(function() {
		if(sampleData) {
			$.get('json/sample.json', function(data) {
				overview.page = JSON.parse(data);
				buildTotalUsers();
				buildTotalMachines();
				buildDatabaseSpaceUsed();
				buildPendingReports();
				generateSampleData(120);
				buildDateRangeCount();
				buildAlertsCounts();
				buildEventLogStatus();
				buildReportsCounts();
				BuildQueuedInspectionReports();
			});
		} else {
			getOverviewData();
		}
		resizeIFrame('#innerFrame');
		overview.widgetInfo = {
			dateRangeCount: {
				target: 'dateRangeCount',
				title: 'Observed Machines by Date',
				info: 'This chart displays the number of machines that have uploaded <strong>valid</strong> metrics by date. By default this widget displays counts for the last 30 days, however, it can be scrolled to display all counts for all days retained within the database. To configure data retention settings, navigate to <strong>Hub Administration > Data Retention > Auto-Delete Settings</strong> tab.', 
			},
			totalMachines: {
				target: 'totalMachines',
				title: 'Observed Machines',
				info: '<p>The observed machine gauge displays the number of machines that have called back today. This number is presented as a percentage of the total number of machines licensed. (For “unlimited” licenses, this value is calculated as a percentage of total machines observed in the inventory). If observed machines are 90% or more, Stratusphere will display this value in red to warn of the limited availability of machine licenses.</p><p>The observed machine value should ideally equal the observed machines by date in the above chart; however, here are a couple of cases where it may differ:</p><ul><li>Machines may be experiencing WMI-related issues, whereby they call back to the Stratusphere Hub but do not have valid metrics. In this case, these call backs will be included in the Observed Machines count, but not in the above chart.</li><li>Collection of metrics has been disabled under the <strong>Hub Administration > Connector ID Keys > Connector ID Key Properties</strong> tab&apos;s Machine Inspection check box. Again, machines will be noted in the Observed Machines count, but not in the above chart.</li></ul>', 
			},
			totalUsers: {
				target: 'totalUsers',
				title: 'Observed Users',
				info: '<p>The Observed Users gauge displays the number of users observed that have called back today. This number is presented as a percentage of the total number of users licensed. (For “unlimited” licenses, this value is calculated as a percentage of total users observed in the inventory). If observed users are 90% or more, Stratusphere will display this value in red to warn of the limited availability of user licenses.</p>', 
			},
			databaseSpaceUsed: {
				target: 'databaseSpaceUsed',
				title: 'Consumed Database Space',
				info: '<p>The Consumed Database Space gauge displays the amount of database storage consumed as a percentage of total allocated disk space. If the usage is less than 65 percent, this value will be displayed in green. If the usage is less than 75 percent, this value will be displayed in yellow. And if less than 25 percent of storage is remaining, this value will be displayed in red, warning of limited available disk space. In this last case, extending available storage to the database should be considered. To do so, you must increase the Age Threshold for auto-delete audit data at <strong>Hub Administration > Data Retention > Auto-Delete Settings</strong> tab.</p>', 
			},
			pendingReports: {
				target: 'pendingReports',
				title: 'Pending CID Key Uploads',
				info: '<p>The Pending CID Key Uploads gauge displays the number of pending CID Key uploads that have not yet been accepted into the Stratusphere Hub appliance. The gauge will display in yellow after 6,000 and red after 10,000 pending uploads. </p><p>The Pending CID Key Uploads value should ideally be zero; however, there are a couple of cases where it may differ:</p><ul><li>Machines are unable to resolve or reach the Stratusphere Hub appliance as it was not available on the network.</li><li>The Stratusphere Hub appliance was either busy or its Pending Database Insertion queue was full; and could not accept data from the CID Key. A restart of Stratusphere Hub services (from within the console) typically resolved this issue.</li></ul><p>The size of the pending upload queue for CID Keys to report to the Stratusphere Hub can be configured by setting the Max. Pending Report Upload Count field under <strong>Hub Administration > Connector ID Keys > Connector ID Key Properties</strong> tab&apos;s Other Properties section.</p>', 
			},
			queuedInspectionReports: {
				target: 'queuedInspectionReports',
				title: 'Pending Database Inserts',
				info: '<p>The Pending Database Inserts gauge displays the number of pending database transactions that have not yet been inserted into the Stratusphere Database appliance. This gauge will display in yellow after 6,000 pending inserts and in red after 10,000 pending inserts.</p><p>The pending Database Inserts value should ideally be zero; however, there are a couple of cases where it may differ:</p><ul><li>The Stratusphere Database appliance may be unreachable.</li><li>The Stratusphere Hub and Database appliances require a higher-performing storage subsystem to meet IOPs (disk speed) requirements.</li><li>Stratusphere Hub appliance services may need to be restarted within the console.</li></ul>', 
			},
			eventLogStatus: {
				target: 'eventLogStatus',
				title: 'Event Log',
				info: '<p>The Event Log chart displays a breakout of Informational, Warning, and Error log types for the Stratusphere Hub appliance. Individual log category types can be hidden by clicking on the name in the legend to the right of the chart. For more detail, navigate to the <strong>Event Log</strong> tab.</p>', 
			},
			alertsCounts: {
				target: 'alertsCounts',
				title: 'Alerts',
				info: '<p>The Alerts chart displays a breakout of generated alert types such as Host, Machine, Network, Storage, etc. Individual alert category types can be hidden by clicking on the name in the legend to the right of the chart. To manage and configure alerts, navigate to <strong>Diagnostics > Alerts</strong> in Stratusphere UX.</p>', 
			},
			reportsCounts: {
				target: 'reportsCounts',
				title: 'Reports',
				info: '<p>The Reports chart displays a breakout of Completed, Running, Failed and Pending report types for Stratusphere. Individual alert category types can be hidden by clicking on the name in the legend to the right of the chart. To manage and run reports, navigate to <strong>Assessment > Reports</strong> in Stratusphere FIT or <strong>Diagnostics >Reports</strong> in Stratusphere UX.</p>', 
			}
		}
	});
	// END ONLOAD
	// INIT Functions
	$(window.parent).on('resize', function() {
		setMaxHeight();
		resizeIFrame('#innerFrame');
	});
	var initOverview = function() {
		//$('#info-modal').clone().appendTo(parent.window.document.body);
		//$('#info-modal').remove();
		buildTotalUsers();
		buildTotalMachines();
		buildDatabaseSpaceUsed();
		buildPendingReports();
		buildDateRangeCount();
		buildAlertsCounts();
		buildEventLogStatus();
		buildReportsCounts();
		BuildQueuedInspectionReports();
		setMaxHeight();
		resizeIFrame('#innerFrame');
		$.each(overview.widgetInfo, function(key,val) {
			createInfoBtn(val.target,val.title,val.info,key);
		});
		$('[data-toggle="popover"]').popover();
		$('.popover').on('shown.bs.popover', function() {
			resizeIFrame('#innerFrame');
		})
		// $('.info-btn').on('click', function() {
		// 	var id = $(this).data('infoid');
		// 	var info = overview.widgetInfo[id];
		// 	$(parent.window.document.body).find('#info-modal .modal-title').html(info.title);
		// 	$(parent.window.document.body).find('#info-modal .modal-body').html(info.info);
		// 	$(parent.window.document.body).find('#info-modal').modal('show')
		// })
	}
	// Helper Functions
	var setMaxHeight = function() {
		var widgets = $('#bottom-row div[class^="col-"]');
		var height = 0;
		$.each(widgets, function() {
			var thisHeight = $(this).height()
			if ( thisHeight > height) {
				height = thisHeight;
			}
		});
		//console.log(height);
		$('#bottom-row div[class^="col-"]').attr('style','height: ' + height + 'px;');
	}
	var createInfoBtn = function(target,title,info,id) {
		html = '';
		html += '<a class="pull-right" tabindex="0" data-viewport="#im-overview" data-html="true" data-container="body" role="button" data-placement="auto left" data-toggle="popover" data-trigger="focus" title="' + title + '" data-content="' + info + '"><i class=" fa fa-info-circle"></i></a>';
		//html += '<a class="pull-right info-btn" data-infoid="' + id + '" role="button" title="' + title + '"><i class=" fa fa-info-circle"></i></a>';
		if(target === 'dateRangeCount') {
			$('#' + target).parent().parent().parent().parent().parent().children('h2').append(html);
		} else {
			$('#' + target).parent().children('.panel-heading').append(html);
		}
	}
	var generateSampleData = function(days) {
		var randomIntFromInterval = function(min,max) {
			return Math.floor(Math.random()*(max-min+1)+min);
		}
		var getFormattedDate = function(date) {
		  var year = date.getFullYear();
		  var month = (1 + date.getMonth()).toString();
		  month = month.length > 1 ? month : '0' + month;
		  var day = date.getDate().toString();
		  day = day.length > 1 ? day : '0' + day;
		  return year + '/' + month + '/' + day;
		}
		var today = new Date().getTime();
		var data = [];
		var row = {};
		for (i = 0; i < days; i++) {
			row.machinecount = randomIntFromInterval(200,500);
			var tmpdate = new Date(today - 86400000);
			row.date = getFormattedDate(tmpdate);
			data.push(row);
			today = tmpdate.getTime();
			row = {};
		}
		overview.page.dateRangeCounts = data;
	}
	var getOverviewData = function() {
		function getCookie(cname) {
		    var name = cname + "=";
		    var ca = document.cookie.split(';');
		    for(var i=0; i<ca.length; i++) {
		        var c = ca[i];
		        while (c.charAt(0)==' ') c = c.substring(1);
		        if (c.indexOf(name) == 0) return c.substring(name.length,c.length);
		    }
		    return "";
		}
		var lwlApiToken = getCookie('lwlApiToken');
		$.ajax({
	        type: 'POST',
	        beforeSend: function()
	        {
	        },
	        success: function()
	        {
	        },
	        cache: true,
	        method: 'GET',
	        headers: {'lwlApiToken': lwlApiToken},
	        url: '/api/v1/overview/system'
	    }).done(function(data, textStatus, jqXHR){
	            console.log(data);
	            overview.page = data;
	            initOverview();
	        }).fail(function(jqXHR,textStatus,errorThrown){
	            console.log(textStatus + ' | ' + errorThrown);
	    });

	}
	var resizeIFrame = function(id) {
		var docHeight,iframe;
		iframe = $(id,window.parent.document);
		docHeight = $('#im-overview').height();
		docHeight = docHeight + 20;
		iframe.attr('style','width: 100%;height: ' + docHeight + 'px');
		iframe.attr('seamless','seamless');
		iframe.attr('scrolling','no');
	}
	// Widgets
	var buildDateRangeCount = function() {
		//fix dates
		$.each(overview.page.dateRangeCounts, function(i) {
			var tempDate = new Date(parseInt(overview.page.dateRangeCounts[i].epochTime));
			// Remove time from date so that it will show properly in amCharts for different time zones
			if (tempDate) {
				var localTime = new Date().toISOString();
                var isoString = tempDate.toISOString().split('T')[0] + 'T' + localTime.split('T')[1];
                overview.page.dateRangeCounts[i].date = new Date(isoString)
            } else {
				console.error('Something was wrong for date: ');
				console.error(overview.page.dateRangeCounts[i]);
			}
		});
		console.log(overview.page.dateRangeCounts);
		if(typeof overview.page.dateRangeCounts !== 'undefined' && overview.page.dateRangeCounts.length > 0) {
			var dateRangeCount = AmCharts.makeChart( "dateRangeCount", {
			  "type": "serial",
			  "theme": "light",
			  "dataProvider": overview.page.dateRangeCounts,
			  "dataDateFormat": "YYYY-MM-DD",
			  "valueAxes": [ {
			    "gridColor": "#CCCCCC",
			    "gridAlpha": 0.2,
			    "dashLength": 0
			  } ],
			  "gridAboveGraphs": false,
			  "startDuration": 1,
				"graphs": [ {
					"id": "g1",
					"balloonText": "<b>Details:</b> [[category]]: <b>[[value]]</b> Machines",
					"fillAlphas": 0.8,
					"lineAlpha": 0.2,
					"type": "column",
					"valueField": "machineCountFromSummaryReports"
				} , {
					"id": "g2",
					"balloonText": "<b>Roll-ups:</b> [[category]]: <b>[[value]]</b> Machines",
					"fillAlphas": 0.2,
					"lineAlpha": 0.4,
					"type": "column",
					"valueField": "machineCountFromSrsDa"
				} ],
			  "mouseWheelZoomEnabled": true,
			  "chartCursor": {
			    "categoryBalloonEnabled": false,
			    "cursorAlpha": 0,
			    "zoomable": true
			  },
			  "path": "js/amcharts/",
			  "svgIcons" : false, // to fix svg icons not appearing
			  "chartScrollbar": {
			    "updateOnReleaseOnly": true,
			    //"autoGridCount": true,
			    //"graph": "g1",
			    //"scrollbarHeight": 20
			  },
			  "categoryField": "date",
			  "categoryAxis": {
			  	"parseDates": true,
			    "gridPosition": "start",
			    "axisColor": "#DADADA",
			    "gridAlpha": 0,
			    "tickPosition": "start",
			    "tickLength": 20,
			    "labelsEnabled": true
			  },
			  "export": {
			    "enabled": true
			  }
			} );
			dateRangeCount.addListener("rendered", zoomChart);
			zoomChart();
			$('#btn-Observed30').on('click', function() {
				zoomChart();
			});
		} 
		else {
			$('#dateRangeCount').html('<div class="alert alert-warning" role="alert">To begin collecting data please install a <a href="/vscenter/app/admin/im-drivers.html" target="_parent">Connector ID Key</a> (Connector ID Keys > Connector ID Key Software).</div>');
		}

		// this method is called when chart is first inited as we listen for "rendered" event
		function zoomChart() {
		    // different zoom methods can be used - zoomToIndexes, zoomToDates, zoomToCategoryValues
		    dateRangeCount.zoomToIndexes(overview.page.dateRangeCounts.length - 30, overview.page.dateRangeCounts.length - 1);
		}

	}
	var buildTotalUsers = function() {
		if(overview.page.totalUsersCalledback >= 0 && overview.page.totalUsersLicensed >= 0) {
			var totalUsersLicensed = overview.page.totalUsersLicensed;
			if(overview.page.totalUsersUnlimited) {
				totalUsersLicensed = totalUsersLicensed + ' (Unlimited)';
			}
			var totalUsers = AmCharts.makeChart( "totalUsers", {
			  "type": "gauge",
			  "theme": "light",
			  "axes": [ {
			    "axisThickness": 1,
			    "axisAlpha": 0.2,
			    "tickAlpha": 0.2,
			    "valueInterval": 20,
			    "bands": [ {
			      "color": "#5cb85c",
			      "endValue": 90,
			      "startValue": 0,
			      "balloonText": overview.page.totalUsersCalledback + " Users called back"
			    }, {
			      "color": "#d9534f",
			      "endValue": 100,
			      //"innerRadius": "95%",
			      "startValue": 90,
			      "balloonText": totalUsersLicensed + " Users Licensed"
			    } ],
			    "bottomText": "0 %",
			    "bottomTextYOffset": -20,
			    "endValue": 100
			  } ],
			  "arrows": [ {
			  	"startWidth": 5
			  } ],
			  "export": {
			    "enabled": true
			  }
			} );
			var value = overview.page.totalUsersLicensed > 0 ? ((parseFloat(overview.page.totalUsersCalledback) / parseFloat(overview.page.totalUsersLicensed))  * 100).toFixed(2) : 0;
			
			//check if percent is greater than 100, if so set to max (100)
			if(value >= 100){
			    value = 100;
			}
			
			$('#totalUsers').parent().children('.module-footer').html('<span class="label label-default center-block">' + overview.page.totalUsersCalledback + ' / ' + totalUsersLicensed + '</span>');
			if ( totalUsers ) {
			    if ( totalUsers.arrows ) {
			      if ( totalUsers.arrows[ 0 ] ) {
			        if ( totalUsers.arrows[ 0 ].setValue ) {
			          totalUsers.arrows[ 0 ].setValue( value );
			          totalUsers.axes[ 0 ].setBottomText( value + " %" );
			        }
			      }
			    }
			}
		} else {
			$('#totalUsers').html('<div class="alert alert-warning" role="alert">Error loading data.</div>');
		}
	}
	var buildTotalMachines = function() {
		if(overview.page.totalMachinesCalledback >= 0 && overview.page.totalMachinesLicensed >= 0) {
			var totalMachinesLicensed = overview.page.totalMachinesLicensed;
			if(overview.page.totalMachinesUnlimited) {
				totalMachinesLicensed = totalMachinesLicensed + ' (Unlimited)';
			}
			var totalMachines = AmCharts.makeChart( "totalMachines", {
			  "type": "gauge",
			  "theme": "light",
			  "axes": [ {
			    "axisThickness": 2,
			    "axisAlpha": 0.2,
			    "tickAlpha": 0.2,
			    "valueInterval": 20,
			    "bands": [ {
			      "color": "#5cb85c",
			      "endValue": 90,
			      "startValue": 0,
			      "balloonText": overview.page.totalMachinesCalledback + " Machines called back"
			    }, {
			      "color": "#d9534f",
			      "endValue": 100,
			      //"innerRadius": "110%",
			      "startValue": 90,
			      "balloonText": totalMachinesLicensed + " Machines Licensed"
			    } ],
			    "bottomText": "0 %",
			    "bottomTextYOffset": -20,
			    "endValue": 100
			  } ],
			  "arrows": [ {
			  	"startWidth": 5
			  } ],
			  "export": {
			    "enabled": true
			  }
			} );
			var value = overview.page.totalMachinesLicensed > 0 ? ((parseFloat(overview.page.totalMachinesCalledback) / parseFloat(overview.page.totalMachinesLicensed))* 100).toFixed(2) : 0;
			
            //check if percent is greater than 100, if so set to max (100)
            if(value >= 100){
                value = 100;
            }
			
			$('#totalMachines').parent().children('.module-footer').html(' <span class="label label-default center-block">' + overview.page.totalMachinesCalledback + ' / ' + totalMachinesLicensed + '</span>');
			if ( totalMachines ) {
			    if ( totalMachines.arrows ) {
			      if ( totalMachines.arrows[ 0 ] ) {
			        if ( totalMachines.arrows[ 0 ].setValue ) {
			          totalMachines.arrows[ 0 ].setValue( value );
			          totalMachines.axes[ 0 ].setBottomText( value + " %" );
			        }
			      }
			    }
			}	
		} else {
			$('#totalMachines').html('<div class="alert alert-warning" role="alert">Error loading Data.</div>');
		}
	}
	var buildDatabaseSpaceUsed = function() {
		if(overview.page.totalDiskSpaceUsed > 0 && overview.page.totalDiskSpaceAllocatedGB > 0) {
			var fillColor = '#5cb85c'; // green

			var totalDiskSpaceUsed = parseFloat(overview.page.totalDiskSpaceUsed).toFixed(2);
			var totalDiskSpaceAllocatedGB = parseFloat(overview.page.totalDiskSpaceAllocatedGB).toFixed(2);
			var totalDiskSpaceUsedPercent = overview.page.use;
			var totalDiskSpaceAllocatedGBPercent = parseFloat((totalDiskSpaceAllocatedGB-totalDiskSpaceUsed)/totalDiskSpaceAllocatedGB*100).toFixed(2);
            if(totalDiskSpaceUsedPercent >= 65.0) {
                fillColor = '#f0ad4e'; // yellow
                if(totalDiskSpaceUsedPercent >= 75.0) {
                    fillColor = '#d9534f'; // red
                }
            }
			var chartData = [ {
			  "category": "Database Space Allocated/Used",
			  "value1": totalDiskSpaceUsedPercent,
			  "value2": totalDiskSpaceAllocatedGBPercent
			} ];
			var databaseSpaceUsed = AmCharts.makeChart( "databaseSpaceUsed", {
			  "theme": "light",
			  "type": "serial",
			  "depth3D": 100,
			  "angle": 30,
			  "autoMargins": false,
			  "marginBottom": 50,
			  "marginLeft": 100,
			  "marginRight": 0,
			  "dataProvider": chartData,
			  "valueAxes": [ {
			    "stackType": "100%",
			    "gridAlpha": 0
			  } ],
			  "graphs": [ {
			    "type": "column",
			    "topRadius": 1,
			    "columnWidth": 1,
			    "showOnAxis": true,
			    "lineThickness": 2,
			    "lineAlpha": 0.5,
			    "lineColor": "#FFFFFF",
			    "fillColors": fillColor,
			    "fillAlphas": 0.8,
			    "valueField": "value1",
			    "balloonText": "<b>" + totalDiskSpaceUsed + "GB/" + totalDiskSpaceUsedPercent + "%</b> Used"
			  }, {
			    "type": "column",
			    "topRadius": 1,
			    "columnWidth": 1,
			    "showOnAxis": true,
			    "lineThickness": 2,
			    "lineAlpha": 0.5,
			    "lineColor": "#cdcdcd",
			    "fillColors": "#cdcdcd",
			    "fillAlphas": 0.5,
			    "valueField": "value2",
			    "balloonText": "<b>" + (totalDiskSpaceAllocatedGB-totalDiskSpaceUsed).toFixed(2) + " GB/" + totalDiskSpaceAllocatedGBPercent + "% Free</b>"
			  } ],

			  "categoryField": "category",
			  "categoryAxis": {
			    "axisAlpha": 0,
			    "labelOffset": 40,
			    "gridAlpha": 0
			  },
			  "export": {
			    "enabled": true
			  }
			} );
			$('#databaseSpaceUsed').parent().children('.module-footer').html(' <span class="label label-default center-block">' + parseFloat(overview.page.totalDiskSpaceUsed).toFixed(2) + 'GB / ' + parseFloat(overview.page.totalDiskSpaceAllocatedGB).toFixed(2) + 'GB</span>');
		} else {
			$('#databaseSpaceUsed').html('<div class="alert alert-warning" role="alert">Error getting data.</div>');
		}	
	}
	var buildPendingReports = function() {
		if(overview.page.totalPendingReports > 0 && overview.page.reportMachinesAffected > 0) {
			var value = parseInt(overview.page.totalPendingReports);
			var machines = parseInt(overview.page.reportMachinesAffected);
			var endValue = function() {
				if(value > 12000) {
					return value + 200;
				} else {
					return 12000;
				}
			}
			var pendingReports = AmCharts.makeChart( "pendingReports", {
			  "type": "gauge",
			  "theme": "light",
			  "axes": [ {
			    "axisThickness": 1,
			    "axisAlpha": 0.2,
			    "tickAlpha": 0.2,
			    "valueInterval": 2000,
			    "usePrefixes": true,
			    "bands": [ {
			      "color": "#5cb85c",
			      "endValue": 6000,
			      "startValue": 0
			    }, {
			      "color": "#f0ad4e",
			      "endValue": 10000,
			      "startValue": 6000
			    }, {
			      "color": "#d9534f",
			      "endValue": endValue(),
			      //"innerRadius": "95%",
			      "startValue": 10000
			    } ],
			    "bottomText": "0 Reports / 0 Machines Affected",
			    "bottomTextYOffset": 20,
			    "endValue": endValue()
			  } ],
			  "arrows": [ {
			  	"startWidth": 5
			  } ],
			  "export": {
			    "enabled": true
			  }
			} );
			$('#pendingReports').parent().children('.module-footer').html(' <span class="label label-default center-block">' + value + ' / ' + machines + '</span>');
			if ( pendingReports ) {
			    if ( pendingReports.arrows ) {
			      if ( pendingReports.arrows[ 0 ] ) {
			        if ( pendingReports.arrows[ 0 ].setValue ) {
			          pendingReports.arrows[ 0 ].setValue( value );
			          pendingReports.axes[ 0 ].setBottomText( value + " Reports / " +  machines + " Machines Affected");
			        }
			      }
			    }
			}
		} else {
			$('#pendingReports').parent().children('.module-footer').html(' <span class="label label-default center-block">0 uploads pending</span>');
			$('#pendingReports').html('<div class="alert alert-success" style="text-align: center;" role="alert"><i class="fa fa-thumbs-o-up fa-5x"></i><br/> 0 uploads pending</div>');
		}
		
	}
	var BuildQueuedInspectionReports = function() {
		if(overview.page.totalQueuedInspectionReports > 0) {
			var value = parseInt(overview.page.totalQueuedInspectionReports);
			var endValue = function() {
				if(value > 12000) {
					return value + 200;
				} else {
					return 12000;
				}
			}
			var queuedInspectionReports = AmCharts.makeChart( "queuedInspectionReports", {
			  "type": "gauge",
			  "theme": "light",
			  "axes": [ {
			    "axisThickness": 1,
			    "axisAlpha": 0.2,
			    "tickAlpha": 0.2,
			    "valueInterval": 2000,
			    "usePrefixes": true,
			    "bands": [ {
			      "color": "#5cb85c",
			      "endValue": 6000,
			      "startValue": 0
			    }, {
			      "color": "#f0ad4e",
			      "endValue": 10000,
			      "startValue": 6000
			    }, {
			      "color": "#d9534f",
			      "endValue": endValue(),
			      //"innerRadius": "95%",
			      "startValue": 10000
			    } ],
			    "bottomText": "0 Reports / 0 Machines Affected",
			    "bottomTextYOffset": 20,
			    "endValue": endValue()
			  } ],
			  "arrows": [ {
			  	"startWidth": 5
			  } ],
			  "export": {
			    "enabled": true
			  }
			} );
			$('#queuedInspectionReports').parent().children('.module-footer').html(' <span class="label label-default center-block">' + value + '</span>');
			if ( queuedInspectionReports ) {
			    if ( queuedInspectionReports.arrows ) {
			      if ( queuedInspectionReports.arrows[ 0 ] ) {
			        if ( queuedInspectionReports.arrows[ 0 ].setValue ) {
			          queuedInspectionReports.arrows[ 0 ].setValue( value );
			          queuedInspectionReports.axes[ 0 ].setBottomText( value + " Queued Reports");
			        }
			      }
			    }
			}
		} else {
			$('#queuedInspectionReports').parent().children('.module-footer').html(' <span class="label label-default center-block">0 database inserts pending</span>');
			$('#queuedInspectionReports').html('<div class="alert alert-success" style="text-align: center;" role="alert"><i class="fa fa-thumbs-o-up fa-5x"></i><br/> 0 database inserts pending</div>');
		}
	}
	var buildAlertsCounts = function() {
		if(typeof overview.page.Alerts !== 'undefined' && overview.page.Alerts.length > 0) {
			var alertsCounts = AmCharts.makeChart( "alertsCounts", {
			  "type": "pie",
			  "theme": "light",
			  "dataProvider": overview.page.Alerts,
			  "valueField": "count",
			  "titleField": "type",
			  "outlineAlpha": 0.4,
			  "labelsEnabled": false,
			  "sequencedAnimation": false,
			  "startDuration": 0,
			  //"depth3D": 15,
			  "balloonText": "[[title]]<br><span style='font-size:14px'><b>[[value]]</b> Alerts</span>",
			  //"angle": 30,
			  "legend": {
			    "position": "right",
			    "markerSize": 8
			  },
			  "export": {
			    "enabled": true
			  }
			} );
		} else {
			
			$('#alertsCounts').html('<div class="alert alert-warning" role="alert">0 Alerts</div>');
		}
		var statustxt = '';
		$.each(overview.page.Alerts, function(i,v) {
			statustxt += overview.page.Alerts[i].type + ': ' + overview.page.Alerts[i].count;
			if(overview.page.Alerts.length > i + 1) {
				statustxt += ' | ';
			}
		});
		$('#alertsCounts').parent().children('.module-footer').html(' <span class="label label-default center-block"><span class="truncate" title="' + statustxt + '">' + statustxt + '</span></span>');
	}
	var buildEventLogStatus = function() {
		if(typeof overview.page.EventLogStatus !== 'undefined' && overview.page.EventLogStatus.length > 0) {
			var eventLogStatus = AmCharts.makeChart( "eventLogStatus", {
			  "type": "pie",
			  "theme": "light",
			  "dataProvider": overview.page.EventLogStatus,
			  "valueField": "count",
			  "titleField": "type",
			  "outlineAlpha": 0.4,
			  "labelsEnabled": false,
			  "sequencedAnimation": false,
			  "startDuration": 0,
			  //"depth3D": 15,
			  "balloonText": "[[title]]<br><span style='font-size:14px'><b>[[value]]</b> Logs</span>",
			  //"angle": 30,
			  "legend": {
			    "position": "right",
			    "markerSize": 8
			  },
			  "export": {
			    "enabled": true
			  }
			} );
		} else {
			$('#eventLogStatus').html('<div class="alert alert-warning" role="alert">0 Logs</div>');
		}
		var statustxt = '';
		$.each(overview.page.EventLogStatus, function(i,v) {
			statustxt += overview.page.EventLogStatus[i].type + ': ' + overview.page.EventLogStatus[i].count;
			if(overview.page.EventLogStatus.length > i + 1) {
				statustxt += ' | ';
			}
		});
		$('#eventLogStatus').parent().children('.module-footer').html(' <span class="label label-default center-block"><span class="truncate" title="' + statustxt + '">' + statustxt + '</span></span>');
	}
	var buildReportsCounts = function() {
		if(typeof overview.page.Reports !== 'undefined' && overview.page.Reports.length > 0 ) {
			var reportsCounts = AmCharts.makeChart( "reportsCounts", {
			  "type": "pie",
			  "theme": "light",
			  "dataProvider": overview.page.Reports,
			  "valueField": "count",
			  "titleField": "type",
			  "outlineAlpha": 0.4,
			  "labelsEnabled": false,
			  "sequencedAnimation": false,
			  "startDuration": 0,
			  //"depth3D": 15,
			  "balloonText": "[[title]]<br><span style='font-size:14px'><b>[[value]]</b> Reports</span>",
			  //"angle": 30,
			  "legend": {
			    "position": "right",
			    "markerSize": 8
			  },
			  "export": {
			    "enabled": true
			  }
			} );
		} else {
			$('#reportsCounts').html('<div class="alert alert-warning" role="alert">0 Reports</div>');
		}
		var statustxt = '';
		$.each(overview.page.Reports, function(i,v) {
			statustxt += overview.page.Reports[i].type + ': ' + overview.page.Reports[i].count;
			if(overview.page.Reports.length > i + 1) {
				statustxt += ' | ';
			}
		});
		$('#reportsCounts').parent().children('.module-footer').html(' <span class="label label-default center-block"><span class="truncate" title="' + statustxt + '">' + statustxt + '</span></span>');
	}
    // END CODE
    // EXPOSE PUBLIC FUNCTIONS
  } // END IIFE
));
