// IIFE
var updates = updates || {};
(function(library) {
    // global jQuery object is passed as a parameter
    library(window.jQuery, window, document);

}(function($, window, document) {
        // BEGIN CODE
        // ONLOAD
        updates.page = {};
        $(function() {
            // Make tabber mess with the DOM first
            tabberOptions = {
                manualStartup: true
            };
            tabberAutomatic(tabberOptions);
            $('#updates-download button').hide();
            initPage();
            setClickHandlers();
        });
        // END ONLOAD
        // INIT Functions
        var initPage = function(callback) {
            $('#updates-progress').hide();
            updates.page.failure = 0;
            updates.page.timeout = 5;
            getUpdatesAvailable();
            resizeIFrame('#innerFrame');
            if(callback && typeof callback === 'function') {
                callback();
            }
        };
        var setClickHandlers = function() {
            $('#updates-nav').on('click', function () {
                resizeIFrame('#innerFrame');
            });
            $('#updates-install button').on('click', function() {
                $('#alerts').empty();
                installUpdate();
                $('#updates-progress').show();
                $('#updates-bar').html('Install in Progress (This may take several minutes)');
                $('#updates-msg').hide();
                $('#updates-install').hide();
                resizeIFrame('#innerFrame');
            });
            $('#updates-download button').on('click', function() {
                $('#updates-msg-online').hide();
                downloadUpdate();
                $('.fieldsetContent').show();
                $('#updates-progress').show();
                $('#updates-bar').html('Download in Progress (This may take several minutes)');
                $('#updates-nav').hide();
                resizeIFrame('#innerFrame');
            });
            $('#updates-upload button').on('click', function() {
                var file = document.getElementById('updateFile').files[0];
                if(file) {
                    var data = new FormData();
                    data.append('updateFile', file);
                    uploadUpdate(data);
                    $('#updates-progress').show();
                    $('.fieldsetContent').show();
                    $('#updates-bar').html('Upload in Progress (This may take several minutes)');
                    $('#updates-text').hide();
                    $('#updates-nav').hide();
                    resizeIFrame('#innerFrame');
                }
                else {
                    createAlert('Please select a file to upload.','warning','uploadalert');
                }
                resizeIFrame('#innerFrame');
            });
            $(window.parent).on('resize', function() {
                resizeIFrame('#innerFrame');
            });
        };
        // Helper Functions
        var createAlert = function(msg,type,id) { // type options: success|info|warning|danger
            if($('#alerts').val() === undefined) {
                $('body').prepend('<div id="alerts"></div>');
            }
            if(id) {
                $('#' + id).remove();
            }
            var idtxt = (id) ? 'id="' + id + '" ' : '';
            (type) ? type : 'info';
            $('#alerts').prepend('<div ' + idtxt + 'class="alert alert-' + type + ' alert-dismissable">\n\t<button type"button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>\n\t<strong>' + msg + '</strong>\n</div>');
            resizeIFrame('#innerFrame');
        };
        var getCookie = function(cname) {
            var name = cname + "=";
            var ca = document.cookie.split(';');
            for(var i=0; i<ca.length; i++) {
                var c = ca[i];
                while (c.charAt(0)==' ') c = c.substring(1);
                if (c.indexOf(name) === 0) return c.substring(name.length,c.length);
            }
            return "";
        };
        var resizeIFrame = function(id) {
            var docHeight,iframe;
            iframe = $(id,window.parent.document);
            docHeight = $('#im-updates').height();
            docHeight = docHeight + $('#alerts').height();
            docHeight = docHeight + 20;
            iframe.attr('style','width: 100%;height: ' + docHeight + 'px');
            iframe.attr('seamless','seamless');
            iframe.attr('scrolling','no');
        };
        var getUpdatesAvailable = function() {
            var lwlApiToken = getCookie('lwlApiToken');
            if(lwlApiToken) {
                $.ajax({
                    beforeSend: function()
                    {
                    },
                    success: function()
                    {
                    },
                    cache: true,
                    method: 'GET',
                    headers: {'lwlApiToken': lwlApiToken},
                    url: '/api/v1/update/available'
                }).done(function(data, textStatus, jqXHR){

                    //console.log(data);
                    updates.page.available = data;
                    if(data.onlineAvailable) {
                        resizeIFrame('#innerFrame');
                    }
                    if(data.version === null) { // fix for when returns empty version object.
                        data.version = {};
                        data.version.version = null;
                    }
                    if(data.onlineAvailable && data.version.version !== null) {
                        //show download form
                        console.log('Online upgrade available');
                        showOnlineTab();
                        $('#updates-msg-online').html('<p style="height:2px;">&nbsp;</p>An update (' + data.version.version + ') is available for download.');
                        if (data.checkPerformed) {
                            $('#updates-download button').show();
                        } else {
                            $('#updates-msg-online').html('<p style="height:2px;">&nbsp;</p>An update (' + data.version.version + ') is available for download. However the check was not performed.');
                        }
                    } else {
                        //show uploads form
                        if(!data.onlineAvailable || data.version.version === null) {
                            console.log('Online not available');
                            showOfflineTab();
                            $('#updates-download button').hide();
                            $('#updates-msg-online').html('<p style="height:2px;">&nbsp;</p>There are no upgrades available.');
                        }
                    }
                    getUpdatesReady();
                    resizeIFrame('#innerFrame');
                }).fail(function(jqXHR,textStatus,errorThrown){
                    createAlert('Unable to get update status - ' + errorThrown,'danger','downloaderror');
                    console.log(textStatus + ' | ' + errorThrown);
                    resizeIFrame('#innerFrame');
                });
            }
        };
        var getUpdatesReady = function() {
            var lwlApiToken = getCookie('lwlApiToken');
            if(lwlApiToken) {
                $.ajax({
                    beforeSend: function()
                    {
                    },
                    success: function()
                    {
                    },
                    cache: true,
                    method: 'GET',
                    headers: {'lwlApiToken': lwlApiToken},
                    url: '/api/v1/update/ready'
                }).done(function(data, textStatus, jqXHR){
                    //console.log(data);
                    updates.page.ready = data;
                    var updateready = false;
                    if(data.length > 0) {
                        $.each(data, function(i,v) {
                            if(data[i].version === updates.page.available.version.version && data[i].build === updates.page.available.version.build) {
                                updateready = true;
                            }
                        });
                    }
                    if(data.length > 0 && updateready) {
                        $('#updates-nav').hide();
                        $('.fieldsetContent').show();
                        $('#updates-install').show();
                        $('#updates-msg').html('<p style="height:2px;">&nbsp;</p>An update is ready to be installed.');
                    }
                    resizeIFrame('#innerFrame');
                }).fail(function(jqXHR,textStatus,errorThrown){
                    createAlert('Unable to get update ready status - ' + errorThrown,'danger','downloaderror');
                    console.log(textStatus + ' | ' + errorThrown);
                    resizeIFrame('#innerFrame');
                });
            }
        };
        var downloadUpdate = function() {
            var lwlApiToken = getCookie('lwlApiToken');
            if(lwlApiToken) {
                $.ajax({
                    beforeSend: function()
                    {
                    },
                    success: function()
                    {
                    },
                    cache: true,
                    method: 'GET',
                    headers: {'lwlApiToken': lwlApiToken},
                    url: '/api/v1/update/download'
                }).done(function(data, textStatus, jqXHR){
                    //console.log(data);
                    updates.page.current = data;
                    getStatus(updates.page.current.id,'download');
                    resizeIFrame('#innerFrame');
                }).fail(function(jqXHR,textStatus,errorThrown){
                    createAlert('Unable to download update - ' + errorThrown,'danger','downloaderror');
                    console.log(textStatus + ' | ' + errorThrown);
                    resizeIFrame('#innerFrame');
                });
            }
        };
        var installUpdate = function() {
            var lwlApiToken = getCookie('lwlApiToken');
            if(lwlApiToken) {
                $.ajax({
                    beforeSend: function()
                    {
                    },
                    success: function()
                    {
                    },
                    cache: true,
                    method: 'GET',
                    headers: {'lwlApiToken': lwlApiToken},
                    url: '/api/v1/update/latest'
                }).done(function(data, textStatus, jqXHR){
                    //console.log(data);
                    updates.page.current = data;
                    getStatus(updates.page.current.id,'install');
                    resizeIFrame('#innerFrame');
                }).fail(function(jqXHR,textStatus,errorThrown){
                    createAlert('Unable to install update - ' + errorThrown,'danger','installerror');
                    console.log(textStatus + ' | ' + errorThrown);
                    resizeIFrame('#innerFrame');
                });
            }
        };
        var uploadUpdate = function(file) {
            var lwlApiToken = getCookie('lwlApiToken');
            if(lwlApiToken) {
                $.ajax({
                    beforeSend: function()
                    {
                    },
                    success: function()
                    {
                    },
                    cache: false,
                    processData: false,
                    contentType: false,
                    method: 'POST',
                    data: file,
                    headers: {'lwlApiToken': lwlApiToken},
                    url: '/api/v1/update/upload'
                }).done(function(data, textStatus, jqXHR){
                    //console.log(data);
                    updates.page.current = data;
                    $('#updates-bar').addClass('progress-bar-success');
                    $('#updates-bar').html('Download Completed.  Verifying image.');
                    getStatus(updates.page.current.id,'upload');
                    resizeIFrame('#innerFrame');
                }).fail(function(jqXHR,textStatus,errorThrown){
                    createAlert('Unable to upload update - ' + errorThrown,'danger','uploaderror');
                    $('#updates-nav').show();
                    console.log(textStatus + ' | ' + errorThrown);
                    resizeIFrame('#innerFrame');
                });
            }
        };
        var getStatus = function(id,type) { // type = upload | download | install
            var lwlApiToken = getCookie('lwlApiToken');
            if(lwlApiToken) {
                $.ajax({
                    beforeSend: function()
                    {
                    },
                    success: function()
                    {
                    },
                    cache: true,
                    method: 'POST',
                    data: {id: id},
                    headers: {'lwlApiToken': lwlApiToken},
                    url: '/api/v1/update/status'
                }).done(function(data, textStatus, jqXHR){
                    //console.log(data);
                    updates.page.current = data;
                    if(updates.page.current.state != 'COMPLETE' && updates.page.current.state != 'INSTALLED' && updates.page.current.state != 'ERROR') {
                        setTimeout(function() { getStatus(updates.page.current.id,type); },5000);
                    } else {
                        if(updates.page.current.state === 'INSTALLED' || updates.page.current.state === 'COMPLETE') {
                            switch(type) {
                                case 'download' :
                                    createAlert('Download completed successfully','success','downloadcomplete');
                                    $('#updates-msg').html('An update is ready to install.');
                                    $('#updates-progress').hide();
                                    $('#updates-install').show();
                                    $('#updates-nav').hide();
                                    resizeIFrame('#innerFrame');
                                    break;
                                case 'upload' :
                                    createAlert('Upload completed successfully','success','uploadcomplete');
                                    $('#updates-msg').html('An update is ready to install.');
                                    $('#updates-progress').hide();
                                    $('#updates-install').show();
                                    $('#updates-nav').hide();
                                    resizeIFrame('#innerFrame');
                                    break;
                                case 'install' :
                                    createAlert('Stratusphere is being upgraded after which the Hub will be rebooted. You will be logged out in 2.5 seconds. Please wait at least 15 minutes to log back in.','success','installcomplete');
                                    $('#updates-progress').hide();
                                    $('#updates-bar').removeClass('progress-bar-success');
                                    $('#updates-install').hide();
                                    $('#im-updates h2').hide();
                                    $('#updates-nav').hide();
                                    resizeIFrame('#innerFrame');
                                    setTimeout(function() { window.top.location.href = '/vscenter/app/logout.html?upgrade=true'; }, 2500);
                                    break;
                            }
                        }
                        else {
                            createAlert('Error:' + updates.page.current.errorMessage,'danger','downloaderror');
                            initPage(function() {
                                $('#updates-nav').show();
                                $('#updates-upload').addClass('tabberactive');
                                $('#updates-download').removeClass('tabberactive');
                            });
                            resizeIFrame('#innerFrame');
                        }
                    }
                }).fail(function(jqXHR,textStatus,errorThrown){
                    console.log(textStatus + ' | ' + errorThrown);
                    if(updates.page.failure > updates.page.timeout) {
                        setTimeout(function() { getStatus(updates.page.current.id,type); },5000);
                        updates.page.failure++;
                    } else {
                        createAlert('Stratusphere is being upgraded after which the Hub will be rebooted. Addtionally, any collectors that are at least at version 6.6.0 will be told to stop collecting data during the hub upgrade process.  Once the hub upgrade is complete, data collection should resume.  You will be logged out in 2.5 seconds. Please wait at least 15 minutes to log back in.','warning','statuserror');
                        setTimeout(function() { window.top.location.href = '/vscenter/app/logout.html?upgrade=true'; }, 2500);
                    }
                    resizeIFrame('#innerFrame');
                });
            }
        };

        function showOfflineTab() {
            $('li > a[title="Online"]').parent().removeClass('tabberactive');
            $('li > a[title="Offline"]').parent().addClass('tabberactive');
            $('#updates-upload').removeClass('tabbertabhide');
            $('#updates-download').addClass('tabbertabhide');
        }

        function showOnlineTab() {
            $('li > a[title="Online"]').parent().addClass('tabberactive');
            $('li > a[title="Offline"]').parent().removeClass('tabberactive');
            $('#updates-download').removeClass('tabbertabhide');
            $('#updates-upload').addClass('tabbertabhide');
        }

        // END CODE
        // EXPOSE PUBLIC FUNCTIONS
    } // END IIFE
));
